@@ -1275,7 +1275,8 @@ pub struct InteractivePayload {
     pub channel: Channel,
     #[serde(default)]
     pub message: Message,
-    #[serde(default)]
+    // We only need this on deserializing.
+    #[serde(default, skip_serializing)]
     pub state: State,
     #[serde(default, skip_serializing_if = "String::is_empty")]
     pub response_url: String,
